@@ -2,17 +2,16 @@ import getpass
 import os
 
 import paramiko
+from dagster import Field, StringSource, check, resource
+from dagster.utils import merge_dicts, mkdir_p
 from paramiko.config import SSH_PORT
 from six import StringIO
 from sshtunnel import SSHTunnelForwarder
 
-from dagster import Field, StringSource, check, resource
-from dagster.utils import merge_dicts, mkdir_p
-
 
 def key_from_str(key_str):
-    '''Creates a paramiko SSH key from a string.'''
-    check.str_param(key_str, 'key_str')
+    """Creates a paramiko SSH key from a string."""
+    check.str_param(key_str, "key_str")
 
     # py2 StringIO doesn't support with
     key_file = StringIO(key_str)
@@ -22,10 +21,10 @@ def key_from_str(key_str):
 
 
 class SSHResource(object):
-    '''
+    """
     Resource for ssh remote execution using Paramiko.
     ref: https://github.com/paramiko/paramiko
-    '''
+    """
 
     def __init__(
         self,
@@ -42,17 +41,17 @@ class SSHResource(object):
         allow_host_key_change=False,
         logger=None,
     ):
-        self.remote_host = check.str_param(remote_host, 'remote_host')
-        self.remote_port = check.opt_int_param(remote_port, 'remote_port')
-        self.username = check.opt_str_param(username, 'username')
-        self.password = check.opt_str_param(password, 'password')
-        self.key_file = check.opt_str_param(key_file, 'key_file')
-        self.timeout = check.opt_int_param(timeout, 'timeout')
-        self.keepalive_interval = check.opt_int_param(keepalive_interval, 'keepalive_interval')
-        self.compress = check.opt_bool_param(compress, 'compress')
-        self.no_host_key_check = check.opt_bool_param(no_host_key_check, 'no_host_key_check')
+        self.remote_host = check.str_param(remote_host, "remote_host")
+        self.remote_port = check.opt_int_param(remote_port, "remote_port")
+        self.username = check.opt_str_param(username, "username")
+        self.password = check.opt_str_param(password, "password")
+        self.key_file = check.opt_str_param(key_file, "key_file")
+        self.timeout = check.opt_int_param(timeout, "timeout")
+        self.keepalive_interval = check.opt_int_param(keepalive_interval, "keepalive_interval")
+        self.compress = check.opt_bool_param(compress, "compress")
+        self.no_host_key_check = check.opt_bool_param(no_host_key_check, "no_host_key_check")
         self.allow_host_key_change = check.opt_bool_param(
-            allow_host_key_change, 'allow_host_key_change'
+            allow_host_key_change, "allow_host_key_change"
         )
         self.log = logger
 
@@ -64,22 +63,22 @@ class SSHResource(object):
         # Auto detecting username values from system
         if not self.username:
             logger.debug(
-                'username to ssh to host: %s is not specified. Using system\'s default provided by'
-                ' getpass.getuser()' % self.remote_host
+                "username to ssh to host: %s is not specified. Using system's default provided by"
+                " getpass.getuser()" % self.remote_host
             )
             self.username = getpass.getuser()
 
-        user_ssh_config_filename = os.path.expanduser('~/.ssh/config')
+        user_ssh_config_filename = os.path.expanduser("~/.ssh/config")
         if os.path.isfile(user_ssh_config_filename):
             ssh_conf = paramiko.SSHConfig()
             ssh_conf.parse(open(user_ssh_config_filename))
             host_info = ssh_conf.lookup(self.remote_host)
-            if host_info and host_info.get('proxycommand'):
-                self.host_proxy = paramiko.ProxyCommand(host_info.get('proxycommand'))
+            if host_info and host_info.get("proxycommand"):
+                self.host_proxy = paramiko.ProxyCommand(host_info.get("proxycommand"))
 
             if not (self.password or self.key_file):
-                if host_info and host_info.get('identityfile'):
-                    self.key_file = host_info.get('identityfile')[0]
+                if host_info and host_info.get("identityfile"):
+                    self.key_file = host_info.get("identityfile")[0]
 
     def get_connection(self):
         """
@@ -90,13 +89,13 @@ class SSHResource(object):
         client = paramiko.SSHClient()
         if not self.allow_host_key_change:
             self.log.warning(
-                'Remote Identification Change is not verified. This won\'t protect against '
-                'Man-In-The-Middle attacks'
+                "Remote Identification Change is not verified. This won't protect against "
+                "Man-In-The-Middle attacks"
             )
             client.load_system_host_keys()
         if self.no_host_key_check:
             self.log.warning(
-                'No Host Key Verification. This won\'t protect against Man-In-The-Middle attacks'
+                "No Host Key Verification. This won't protect against Man-In-The-Middle attacks"
             )
             # Default is RejectPolicy
             client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
@@ -131,15 +130,15 @@ class SSHResource(object):
 
         return client
 
-    def get_tunnel(self, remote_port, remote_host='localhost', local_port=None):
-        check.int_param(remote_port, 'remote_port')
-        check.str_param(remote_host, 'remote_host')
-        check.opt_int_param(local_port, 'local_port')
+    def get_tunnel(self, remote_port, remote_host="localhost", local_port=None):
+        check.int_param(remote_port, "remote_port")
+        check.str_param(remote_host, "remote_host")
+        check.opt_int_param(local_port, "local_port")
 
         if local_port is not None:
-            local_bind_address = ('localhost', local_port)
+            local_bind_address = ("localhost", local_port)
         else:
-            local_bind_address = ('localhost',)
+            local_bind_address = ("localhost",)
 
         # Will prefer key string if specified, otherwise use the key file
         pkey = self.key_obj if self.key_obj else self.key_file
@@ -172,8 +171,8 @@ class SSHResource(object):
         return client
 
     def sftp_get(self, remote_filepath, local_filepath):
-        check.str_param(remote_filepath, 'remote_filepath')
-        check.str_param(local_filepath, 'local_filepath')
+        check.str_param(remote_filepath, "remote_filepath")
+        check.str_param(local_filepath, "local_filepath")
         conn = self.get_connection()
         with conn.open_sftp() as sftp_client:
             local_folder = os.path.dirname(local_filepath)
@@ -182,7 +181,7 @@ class SSHResource(object):
             mkdir_p(local_folder)
 
             self.log.info(
-                'Starting to transfer from {0} to {1}'.format(remote_filepath, local_filepath)
+                "Starting to transfer from {0} to {1}".format(remote_filepath, local_filepath)
             )
 
             sftp_client.get(remote_filepath, local_filepath)
@@ -191,12 +190,12 @@ class SSHResource(object):
         return local_filepath
 
     def sftp_put(self, remote_filepath, local_filepath, confirm=True):
-        check.str_param(remote_filepath, 'remote_filepath')
-        check.str_param(local_filepath, 'local_filepath')
+        check.str_param(remote_filepath, "remote_filepath")
+        check.str_param(local_filepath, "local_filepath")
         conn = self.get_connection()
         with conn.open_sftp() as sftp_client:
             self.log.info(
-                'Starting to transfer file from {0} to {1}'.format(local_filepath, remote_filepath)
+                "Starting to transfer file from {0} to {1}".format(local_filepath, remote_filepath)
             )
 
             sftp_client.put(local_filepath, remote_filepath, confirm=confirm)
@@ -207,51 +206,51 @@ class SSHResource(object):
 
 @resource(
     {
-        'remote_host': Field(
-            StringSource, description='remote host to connect to', is_required=True
+        "remote_host": Field(
+            StringSource, description="remote host to connect to", is_required=True
         ),
-        'remote_port': Field(
+        "remote_port": Field(
             int,
-            description='port of remote host to connect (Default is paramiko SSH_PORT)',
+            description="port of remote host to connect (Default is paramiko SSH_PORT)",
             is_required=False,
             default_value=SSH_PORT,
         ),
-        'username': Field(
-            StringSource, description='username to connect to the remote_host', is_required=False
+        "username": Field(
+            StringSource, description="username to connect to the remote_host", is_required=False
         ),
-        'password': Field(
+        "password": Field(
             StringSource,
-            description='password of the username to connect to the remote_host',
+            description="password of the username to connect to the remote_host",
             is_required=False,
         ),
-        'key_file': Field(
+        "key_file": Field(
             StringSource,
-            description='key file to use to connect to the remote_host.',
+            description="key file to use to connect to the remote_host.",
             is_required=False,
         ),
-        'key_string': Field(
+        "key_string": Field(
             StringSource,
-            description='key string to use to connect to remote_host',
+            description="key string to use to connect to remote_host",
             is_required=False,
         ),
-        'timeout': Field(
+        "timeout": Field(
             int,
-            description='timeout for the attempt to connect to the remote_host.',
+            description="timeout for the attempt to connect to the remote_host.",
             is_required=False,
             default_value=10,
         ),
-        'keepalive_interval': Field(
+        "keepalive_interval": Field(
             int,
-            description='send a keepalive packet to remote host every keepalive_interval seconds',
+            description="send a keepalive packet to remote host every keepalive_interval seconds",
             is_required=False,
             default_value=30,
         ),
-        'compress': Field(bool, is_required=False, default_value=True),
-        'no_host_key_check': Field(bool, is_required=False, default_value=True),
-        'allow_host_key_change': Field(bool, is_required=False, default_value=False),
+        "compress": Field(bool, is_required=False, default_value=True),
+        "no_host_key_check": Field(bool, is_required=False, default_value=True),
+        "allow_host_key_change": Field(bool, is_required=False, default_value=False),
     }
 )
 def ssh_resource(init_context):
     args = init_context.resource_config
-    args = merge_dicts(init_context.resource_config, {'logger': init_context.log_manager})
+    args = merge_dicts(init_context.resource_config, {"logger": init_context.log_manager})
     return SSHResource(**args)
